bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution
===============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. autoclass:: MultinomialDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~MultinomialDistribution.__init__
      ~MultinomialDistribution.compute_cgf_from_parents
      ~MultinomialDistribution.compute_fixed_moments_and_f
      ~MultinomialDistribution.compute_gradient
      ~MultinomialDistribution.compute_logpdf
      ~MultinomialDistribution.compute_mask_to_parent
      ~MultinomialDistribution.compute_message_to_parent
      ~MultinomialDistribution.compute_moments_and_cgf
      ~MultinomialDistribution.compute_phi_from_parents
      ~MultinomialDistribution.plates_from_parent
      ~MultinomialDistribution.plates_to_parent
      ~MultinomialDistribution.random
   
   

   
   
   